@@ -1,8 +1,6 @@
 """
-act.qc.radiometer_tests
-------------------------------
+Tests specific to radiometers.
 
-Tests specific to radiometers
 """
 
 from scipy.fftpack import rfft, rfftfreq
