@@ -18,6 +18,29 @@ def test_fft_shading_test():
     assert np.nansum(qc_data.values) == 456
 
 
+def test_global_qc_cleanup():
+    ds_object = read_netcdf(EXAMPLE_MET1)
+    ds_object.load()
+    ds_object.clean.cleanup()
+
+    assert ds_object['qc_wdir_vec_mean'].attrs['flag_meanings'] == [
+        'Value is equal to missing_value.', 'Value is less than the fail_min.',
+        'Value is greater than the fail_max.']
+    assert ds_object['qc_wdir_vec_mean'].attrs['flag_masks'] == [1, 2, 4]
+    assert ds_object['qc_wdir_vec_mean'].attrs['flag_assessments'] == ['Bad', 'Bad', 'Bad']
+
+    assert ds_object['qc_temp_mean'].attrs['flag_meanings'] == [
+        'Value is equal to missing_value.', 'Value is less than the fail_min.',
+        'Value is greater than the fail_max.',
+        'Difference between current and previous values exceeds fail_delta.']
+    assert ds_object['qc_temp_mean'].attrs['flag_masks'] == [1, 2, 4, 8]
+    assert ds_object['qc_temp_mean'].attrs['flag_assessments'] == ['Bad', 'Bad',
+                                                                   'Bad', 'Indeterminate']
+
+    ds_object.close()
+    del ds_object
+
+
 def test_qc_test_errors():
     ds_object = read_netcdf(EXAMPLE_MET1)
     var_name = 'temp_mean'
@@ -132,7 +155,7 @@ def test_qcfilter():
     # tests are set.
     assert np.sum(ds_object.qcfilter.get_qc_test_mask(
         var_name, result['test_number'], return_index=True) -
-        np.array(index, dtype=np.int)) == 0
+        np.array(index, dtype=int)) == 0
 
     # Unset a test
     ds_object.qcfilter.unset_test(var_name, index=0,
@@ -550,13 +573,14 @@ def test_qctests_dos():
     data = ds_object[var_name].values
     data[1000:2500] = data[1000]
     ds_object[var_name].values = data
-    ds_object.qcfilter.add_persistence_test(var_name)
-    qc_var_name = ds_object.qcfilter.check_for_ancillary_qc(
-        var_name, add_if_missing=False, cleanup=False, flag_type=False)
+    result = ds_object.qcfilter.add_persistence_test(var_name)
+    qc_var_name = result['qc_variable_name']
     test_meaning = ('Data failing persistence test. Standard Deviation over a '
                     'window of 10 values less than 0.0001.')
     assert ds_object[qc_var_name].attrs['flag_meanings'][-1] == test_meaning
-    assert np.sum(ds_object[qc_var_name].values) == 1500
+    # There is a precision issue with GitHub testing that makes the number of tests
+    # tripped off by 1. This isclose() option is to account for that.
+    assert np.isclose(np.sum(ds_object[qc_var_name].values), 1500, atol=1)
 
     ds_object.qcfilter.add_persistence_test(var_name, window=10000, prepend_text='DQO')
     test_meaning = ('DQO: Data failing persistence test. Standard Deviation over a window of '
